@@ -204,7 +204,7 @@ def augment_and_train(model, GCS_DS_PATH, train_tfrec_path, val_tfrec_path, batc
 	
 		if epoch == 0:
 			print(f"\nEpoch # {epoch + 1}\n")
-			print(f"\nCurrent Learning Rate -> {K.eval(model.optimizer.lr}")
+			print(f"\nCurrent Learning Rate -> {K.eval(model.optimizer.lr)}")
 			history = model.fit(get_training_dataset(GCS_DS_PATH, train_tfrec_path, batch_size, augmentation = True), validation_data = get_validation_dataset(GCS_DS_PATH, val_tfrec_path, batch_size, augmentation = True), epochs = 1, steps_per_epoch = steps_per_epoch, batch_size = batch_size, verbose = 1)
 			if callbacks is not None:
 				set_callbacks(model, epoch + 1, callbacks)
@@ -216,7 +216,7 @@ def augment_and_train(model, GCS_DS_PATH, train_tfrec_path, val_tfrec_path, batc
 		else:
 		
 			print(f"\nEpoch # {epoch + 1}\n")
-			print(f"\nCurrent Learning Rate -> {K.eval(model.optimizer.lr}")
+			print(f"\nCurrent Learning Rate -> {K.eval(model.optimizer.lr)}")
 			history = model.fit(get_training_dataset(GCS_DS_PATH, train_tfrec_path, batch_size, augmentation = True), validation_data = get_validation_dataset(GCS_DS_PATH, val_tfrec_path, batch_size, augmentation = True), epochs = 1, steps_per_epoch = steps_per_epoch, batch_size = batch_size, verbose = 1)
 			if callbacks is not None:
 				set_callbacks(model, epoch + 1, callbacks)
